package com.ruoyi.dxp.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.dxp.domain.DataIntegration;
import com.ruoyi.dxp.dto.DataIntegrationBatch;
import com.ruoyi.dxp.dto.DataIntegrationDto;
import com.ruoyi.dxp.dto.MetaDataSave;

/**
 * 整合数据Service接口
 * 
 * @author jy
 * @date 2022-11-12
 */
public interface IDataIntegrationService 
{
    /**
     * 查询整合数据
     * 
     * @param id 整合数据主键
     * @return 整合数据
     */
    public DataIntegrationDto selectDataIntegrationById(Long id);

    /**
     * 查询整合数据列表
     * 
     * @param dataIntegration 整合数据
     * @return 整合数据集合
     */
    public List<DataIntegration> selectDataIntegrationList(DataIntegration dataIntegration);

    /**
     * 新增整合数据
     * 
     * @param dataIntegration 整合数据
     * @return 结果
     */
    public AjaxResult insertDataIntegration(DataIntegration dataIntegration);

    /**
     * 挂载
     * @param dataIntegrationBatch
     * @return
     */
    public AjaxResult batchDataIntegration(DataIntegrationBatch dataIntegrationBatch);

    /**
     * 修改整合数据
     * 
     * @param dataIntegration 整合数据
     * @return 结果
     */
    public int updateDataIntegration(DataIntegration dataIntegration);

//    /**
//     * 批量删除整合数据
//     *
//     * @param ids 需要删除的整合数据主键集合
//     * @return 结果
//     */
//    public int deleteDataIntegrationByIds(Long[] ids);

    /**
     * 删除整合数据信息
     * 
     * @param id 整合数据主键
     * @return 结果
     */
    public AjaxResult deleteDataIntegrationById(Long id);

    /**
     * 从数据源同步整合数据
     * @param databaseId 数据源id
     */
    public void syncFromDatabase(Long databaseId);

    /**
     * 保存元数据
     * @param metaDataSave 元数据保存对象
     * @return 保存结果
     */
    public AjaxResult saveMetadata(MetaDataSave metaDataSave) throws Exception;

    /**
     * 查询元数据数据
     * @param id id
     * @return 结果
     */
    public AjaxResult getData(Long id, Integer page, Integer pageSize);
}
